<?php

namespace Drupal\remote_file_importer;

use Drupal\Component\Plugin\PluginInspectionInterface;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines an interface for Color plugin plugins.
 */
interface DataSourcePluginInterface extends PluginInspectionInterface {

  /**
   * Return the plugins label.
   *
   * @return string
   *   Returns the label as a string.
   */
  public function getLabel();

  /**
   * Create speficic settings for data source.
   *
   * @return array
   *   Render array for settings form.
   */
  public function getSettingsForm(array $values = []);

  /**
   * Custom validation for settings form.
   *
   * @return array
   *   Render array for settings form.
   */
  public function validateSettingsForm(array &$form, FormStateInterface $form_state);

  /**
   * Login to remote service.
   *
   * @param array $settings
   *   Array of settings required to establish connection.
   *
   * @return bool
   *   Returns whether the connection has been setup successfully.
   */
  public function establishConnection(array $settings);

  /**
   * Get a list of files to be imported.
   *
   * @return array
   *   List of paths.
   */
  public function collectFiles();

  /**
   * Imports a single file.
   *
   * @param string $localFileName
   *   Target filename.
   * @param string $remoteFileName
   *   Source filename on remote service.
   *
   * @return bool
   *   Returns whether the file has been imported successfully.
   */
  public function importFile(string $localFileName, string $remoteFileName);

  /**
   * Close connection.
   */
  public function closeConnection();

}
